@@ -27,7 +27,7 @@ xml_output = qgc.request(call, parameters, concurrent_scans_retries=2, concurren
 #         <errorResolution>Please wait until your previous scans have completed</errorResolution>
 #       </responseErrorDetails>
 #
-print xml_output
+print(xml_output)
 #
 # API v1 call: Print out all IPs associated with asset group "Looneyville Texas".
 # Note that the question mark at the end is optional.
@@ -37,9 +37,9 @@ parameters = 'title=Looneyville Texas'
 # Let's call the API and store the result in xml_output.
 xml_output = qgc.request(call, parameters)
 # Let's objectify the xml_output string.
-root = objectify.fromstring(xml_output)
+root = objectify.fromstring(xml_output.encode('utf-8'))
 # Print out the IPs.
-print root.ASSET_GROUP.SCANIPS.IP.text
+print(root.ASSET_GROUP.SCANIPS.IP.text)
 # Prints out:
 # 10.0.0.102
 #
@@ -47,10 +47,10 @@ print root.ASSET_GROUP.SCANIPS.IP.text
 call = '/api/2.0/fo/asset/host/'
 parameters = {'action': 'list', 'ips': '10.0.0.10-10.0.0.11'}
 xml_output = qgc.request(call, parameters)
-root = objectify.fromstring(xml_output)
+root = objectify.fromstring(xml_output.encode('utf-8'))
 # Iterate hosts and print out DNS name.
 for host in root.RESPONSE.HOST_LIST.HOST:
-    print host.IP.text, host.DNS.text
+    print(host.IP.text, host.DNS.text)
 # Prints out:
 # 10.0.0.10 mydns1.qualys.com
 # 10.0.0.11 mydns2.qualys.com
@@ -59,9 +59,9 @@ for host in root.RESPONSE.HOST_LIST.HOST:
 call = '/count/was/webapp'
 # Note that this call does not have a payload so we don't send any data parameters.
 xml_output = qgc.request(call)
-root = objectify.fromstring(xml_output)
+root = objectify.fromstring(xml_output.encode('utf-8'))
 # Print out count of webapps.
-print root.count.text
+print(root.count.text)
 # Prints out:
 # 89
 #
@@ -70,9 +70,9 @@ call = '/count/was/webapp'
 # We can send a string XML for the data.
 parameters = '<ServiceRequest><filters><Criteria operator="CONTAINS" field="name">Supafly</Criteria></filters></ServiceRequest>'
 xml_output = qgc.request(call, parameters)
-root = objectify.fromstring(xml_output)
+root = objectify.fromstring(xml_output.encode('utf-8'))
 # Print out count of webapps.
-print root.count.text
+print(root.count.text)
 # Prints out:
 # 3
 #
@@ -84,9 +84,9 @@ parameters = (
         E.filters(
             E.Criteria('Lightsabertooth Tiger', field='name',operator='CONTAINS'))))
 xml_output = qgc.request(call, parameters)
-root = objectify.fromstring(xml_output)
+root = objectify.fromstring(xml_output.encode('utf-8'))
 # Print out count of webapps.
-print root.count.text
+print(root.count.text)
 # Prints out:
 # 0
 # Too bad, because that is an awesome webapp name!
@@ -94,9 +94,9 @@ print root.count.text
 # API v3 Asset Management call: Count tags.
 call = '/count/am/tag'
 xml_output = qgc.request(call)
-root = objectify.fromstring(xml_output)
+root = objectify.fromstring(xml_output.encode('utf-8'))
 # We can use XPATH to find the count.
-print root.xpath('count')[0].text
+print(root.xpath('count')[0].text)
 # Prints out:
 # 840
 #
