@@ -10,7 +10,7 @@ import qualysapi
 if __name__ == '__main__':
     # Basic command line processing.
     if len(sys.argv) != 2:
-        print 'A single IPv4 address is expected as the only argument'
+        print('A single IPv4 address is expected as the only argument')
         sys.exit(2)
     
     # Set the MAXIMUM level of log messages displayed @ runtime. 
@@ -39,4 +39,4 @@ if __name__ == '__main__':
     # New way is cleaner:
     ret = qgs.request(1,'asset_search.php', {'target_ips': sys.argv[1]})
 
-    print ret
+    print(ret)
