@@ -1,18 +1,19 @@
-''' Module to hold global settings reused throughout qualysapi. '''
+""" Module to hold global settings reused throughout qualysapi. """
 
 __author__ = "Colin Bell <colin.bell@uwaterloo.ca>"
 __copyright__ = "Copyright 2011-2013, University of Waterloo"
 __license__ = "BSD-new"
 
+import os
+
+
 global defaults
 global default_filename
 
-import os
 
-if os.name == 'nt':
+if os.name == "nt":
     default_filename = "config.ini"
 else:
     default_filename = ".qcrc"
 
-defaults = {'hostname': 'qualysapi.qualys.com',
-            'max_retries': '3'}
+defaults = {"hostname": "qualysapi.qualys.com", "max_retries": "3", "template_id": "00000"}
